aboutsummaryrefslogtreecommitdiff
path: root/EfiGuardDxe/util.h
diff options
context:
space:
mode:
authorMatthijs Lavrijsen <mattiwatti@gmail.com>2021-01-30 04:42:06 +0100
committerMatthijs Lavrijsen <mattiwatti@gmail.com>2021-01-30 04:42:06 +0100
commitf8ca8c0c008980352c2b3eee6eda21f395bde4cf (patch)
tree85338bffac330fd39700d45c6c0828d83d3651d6 /EfiGuardDxe/util.h
parentdceaa9c1c416fc68e3a9e29db34cd04d83cb76ec (diff)
Use PE runtime function tables for finding function start addressesv1.1.1
Diffstat (limited to 'EfiGuardDxe/util.h')
-rw-r--r--EfiGuardDxe/util.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/EfiGuardDxe/util.h b/EfiGuardDxe/util.h
index f25c3d6..c306a0e 100644
--- a/EfiGuardDxe/util.h
+++ b/EfiGuardDxe/util.h
@@ -42,6 +42,7 @@ AppendKernelPatchMessage(
VOID
EFIAPI
PrintKernelPatchInfo(
+ VOID
);
//
@@ -51,6 +52,7 @@ PrintKernelPatchInfo(
BOOLEAN
EFIAPI
WaitForKey(
+ VOID
);
//
@@ -108,13 +110,13 @@ ZydisInit(
);
//
// Finds the start of a function given an address within it, scanning downwards.
// Returns NULL if StartAddress is NULL (this simplifies error checking logic in calling functions).
// Returns NULL if LowerBound is reached and no function boundary was found.
//
UINT8*
EFIAPI
BacktrackToFunctionStart(
- IN CONST UINT8* StartAddress,
- IN CONST UINT8* LowerBound
+ IN CONST UINT8* ImageBase,
+ IN PEFI_IMAGE_NT_HEADERS NtHeaders,
+ IN CONST UINT8* AddressInFunction
);
@@ -108,13 +110,13 @@ ZydisInit(
);
//
-// Finds the start of a function given an address within it, scanning downwards.
-// Returns NULL if StartAddress is NULL (this simplifies error checking logic in calling functions).
-// Returns NULL if LowerBound is reached and no function boundary was found.
+// Finds the start of a function given an address within it.
+// Returns NULL if AddressInFunction is NULL (this simplifies error checking logic in calling functions).
//
UINT8*